<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;

use Appweb\Libraries\Util;
use Appweb\Fornecedor;
use Appweb\Pagamento;
use Appweb\Parcela;
use Appweb\Caixa;
use Appweb\Provisionado;
use Carbon\Carbon;
use Auth;
use DB;

class ContasPagarController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        
        if ($request->has('filtro')) {

            if ($request->has('fornecedor')) {

                if ($request->filtro == "A vencer") {

                    $busca = Parcela::with('pagamento', 'fornecedor')
                        ->where("fornecedor_id", $request->fornecedor)
                        ->whereRaw("
                            date(vencimento) between '{$request->datainicial}' and '{$request->datafinal}'
                            ")
                            ->where('saldo', '>', 0)
                            ->whereNotNull('pagamento_id')
                            ->orderBy('vencimento')
                            ->paginate(15);
                    
                } else if ($request->filtro == "Quitadas") {

                    $busca = Parcela::with('pagamento', 'fornecedor')
                        ->where("fornecedor_id", $request->fornecedor)
                        ->whereRaw("
                            date(quitacao) between '{$request->datainicial}' and '{$request->datafinal}'
                            ")
                            ->where('saldo', 0)
                            ->whereNotNull('pagamento_id')
                            ->orderBy('vencimento')
                            ->paginate(15);

                }

            } else {

                if ($request->filtro == "A vencer") {

                    $busca = Parcela::with('pagamento', 'fornecedor')->whereRaw("
                        date(vencimento) between '{$request->datainicial}' and '{$request->datafinal}'
                        ")
                        ->where('saldo', '>', 0)
                        ->whereNotNull('pagamento_id')
                        ->orderBy('vencimento')
                        ->paginate(15);

                } else if ($request->filtro == "Quitadas") {

                   $busca = Parcela::with('pagamento', 'fornecedor')->whereRaw("
                        date(quitacao) between '{$request->datainicial}' and '{$request->datafinal}'
                        ")
                        ->where('saldo', 0)
                        ->whereNotNull('pagamento_id')
                        ->orderBy('vencimento')
                        ->paginate(15);

                }
                
            }
        
        } else {
            
            if (env('DB_CONNECTION') == 'sqlite') {

                $busca = Parcela::with('pagamento', 'fornecedor')->whereRaw("
                    date(vencimento) > datetime('now', '-7 DAY') 
                    ")
                    ->where('saldo', '>', 0)
                    ->whereNotNull('pagamento_id')
                    ->orderBy('id', 'desc')
                    ->paginate(15);

            } else {

                if ($request->has('busca')) {

                    $busca = Parcela::with('pagamento', 'fornecedor')->whereHas('fornecedor', function($q) use ($request) {
                        $q->where('nome', 'like', '%'.$request->busca.'%');
                        $q->orWhere('fornecedor_id', $request->busca);
                    })
                        ->where('saldo', '>', 0)
                        ->whereNotNull('pagamento_id')
                        ->orderBy('id', 'desc')
                        ->paginate(15);

                } else {

                    $busca = Parcela::with('pagamento', 'fornecedor')->whereRaw("
                        date(vencimento) BETWEEN CURRENT_DATE - INTERVAL 7 DAY AND CURRENT_DATE
                        ")
                        ->where('saldo', '>', 0)
                        ->whereNotNull('pagamento_id')
                        ->orderBy('id', 'desc')
                        ->paginate(15);

                }

            }

        }
        
        // dd($busca);
        $soma = $busca->sum('valor');
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        return view('pages.contaspagar.index', compact('busca', 'soma', 'fornecedores'))
            ->with("modulo", "Contas a Pagar");

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        return view('pages.contaspagar.form', compact('fornecedores'))
            ->with("modulo", "Contas a Pagar")
            ->with('legenda', 'Pagamento');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
        
        // $dt = Carbon::createFromFormat('Y-m-d', $request->vencimento);

        // for ($i=1; $i <= $request->parcelas; $i++) {

        //     if ($dt->dayOfWeek == Carbon::SUNDAY) {
        //         $dt->addDays(1);
        //     } else {
        //         $dt->addDay();
        //     }
        //     echo ( $dt->dayOfWeek ) . '<br>';

        // }

        // exit();
        
        $valor = Util::toFloat($request->valor);
        // return $valor;
        
        if ($valor > 0) {

            $regras = [
                'vencimento'=>'required', 
                'fornecedor'=>'required', 
                'valor'=>'required', 
                // 'banco'=>'required',
                'parcelas'=>'required',
                'observacoes'=>'required',
                ];
            $mensagens = [
                'vencimento.required'=>'Preencha o Vencimento', 
                'fornecedor.required'=>'Selecione o Fornecedor', 
                'valor.required'=>'Informe o Valor Total', 
                // 'banco.required'=>'Informe o Banco',
                'parcelas'=>'Informe o número de Parcelas',
                'observacoes.required'=>'Preencha as Observações',
                ];
            $this->validate($request,$regras,$mensagens);
            $conta = Pagamento::create([
                'emissao'=>date('Y-m-d H:i:s'),
                'vencimento'=>$request->vencimento,
                'documento'=>$request->documento,
                'fornecedor_id'=>$request->fornecedor, 
                'valor'=>Util::toFloat($request->valor),
                'parcelas_conta'=>$request->parcelas,
                'banco'=>$request->banco,
                'usuario_id'=>Auth::user()->id,
                'observacoes'=>$request->observacoes,
                'status'=>'Pendente',
                ]);
            
            $p = Util::toFloat($request->valor) / intval($request->parcelas);
            $dt = Carbon::createFromFormat('Y-m-d', $request->vencimento);

            if ($request->has('repetir') && $request->has('periodo')) {

                for ($i=1; $i <= $request->parcelas; $i++) { 

                    $parcela = new Parcela;
                    $parcela->pagamento_id  = $conta->id;
                    $parcela->parcela       = $i;
                    $parcela->documento     = ($request->has('documento')) ? $request->documento.'-'.$i.'/'.$request->parcelas : $i.'/'.$request->parcelas;
                    $parcela->vencimento    = $dt->startOfDay();
                    $parcela->valor         = $p;
                    $parcela->saldo         = $p;
                    $parcela->fornecedor_id = $request->fornecedor;
                    $parcela->save();

                    switch ($request->periodo) {
                        case "Dias":
                            $dt->addDay(); 
                            break;
                        case "Semanas":
                            $dt->addWeek();
                            break;
                        case "Meses":
                            $dt->addMonth();
                            break;
                        case "Anos":
                            $dt->addYear();
                            break;
                        default:
                            // 
                            break;
                    }

                }

            } else {

                Parcela::create([
                    'pagamento_id'=>$conta->id, 
                    'parcela'=>1,
                    'documento'=>($request->has('documento')) ? $request->documento.'-1/1' : '1/1',
                    'vencimento'=>$dt,
                    'valor'=>$p,
                    'saldo'=>$p,
                    'fornecedor_id'=>$request->fornecedor,
                    ]);

            }

            return redirect('contaspagar');

        } else {

            return redirect()->back()->withInput()->withErrors(['Valor inválido!']);

        }        

    }

    public function informarPagamento(Request $request)
    {
        
        // dd( $request );
        $provisionado = Util::provisionado();
        $parcela = Parcela::with('fornecedor', 'pagamento')->find($request->pagamento);
        // dd($parcela);
        $parcela->valor_pago = Util::toFloat($request->valor);
        $parcela->valor = Util::toFloat($request->valor);
        $parcela->saldo = $parcela->saldo - Util::toFloat($request->valor);
        $parcela->save();
        // Caixa::create([
        //     'registro' => $request->pagamento,
        //     'formapagamento' => $request->tipo,
        //     'tipomovimento' => 'Pagamento',
        //     'bandeiracartao' => $request->bandeiracartao,
        //     'valor' => Util::toFloat($request->valor),
        //     'data' => date("Y-m-d H:i:s"),
        //     'observacoes' => "PAGAMENTO - " . $parcela->pagamento->fornecedor->nome . " (" . $parcela->documento . ")",
        //     'movimento' => "S",
        // ]);
        $provisionado->saldo = $provisionado->saldo - Util::toFloat($request->valor);
        $provisionado->save();
        $parcela->update([
            'saldo'=>0,
            'quitacao'=>$request->datapagamento,
            'fornecedor'=>$parcela->fornecedor,
            ]);
        if ($parcela->saldo == 0) {
            $parcela->pagamento->status = "Pago";
        }
        $parcela->pagamento->tipo_pagamento = $request->tipo;
        if ($request->has('bandeira_cartao')) {
            $parcela->pagamento->parcelas_cartao = $request->parcelas_cartao;
            $parcela->pagamento->bandeira_cartao = $request->bandeira_cartao;
        }
        $parcela->pagamento->valor_pago = $parcela->valor;
        $parcela->pagamento->pagamento = Carbon::now();
        $parcela->pagamento->save();
        return redirect()->back();

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id="")
    {

        if (!empty($id)) {
            $pagamento = Pagamento::find($id);
            // dd($pagamento);
            $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
            return view('pages.contaspagar.form', compact('pagamento', 'fornecedores'))
                ->with('legenda', 'Edição');            
        } else {
            return redirect()->back();
        }

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update(Request $request, $id)
    {
        $valor = Util::toFloat($request->valor);
        // return $valor;
        
        if ($valor > 0) {

            $regras = [
                'vencimento'=>'required', 
                'fornecedor'=>'required', 
                'valor'=>'required', 
                'banco'=>'required',
                // 'parcelas'=>'required',
                'observacoes'=>'required',
                ];
            $mensagens = [
                'vencimento.required'=>'Preencha o Vencimento', 
                'fornecedor.required'=>'Selecione o Fornecedor', 
                'valor.required'=>'Informe o Valor Total', 
                'banco.required'=>'Informe o Banco',
                // 'parcelas'=>'Informe o número de Parcelas',
                'observacoes.required'=>'Preencha as Observações',
                ];
            $this->validate($request,$regras,$mensagens);
            $conta = Pagamento::find($id);
            $conta->update([
                // 'emissao'=>date('Y-m-d H:i:s'),
                // 'vencimento'=>$request->vencimento,
                'documento'=>$request->documento,
                'fornecedor_id'=>$request->fornecedor, 
                'valor'=>Util::toFloat($request->valor),
                'banco'=>$request->banco,
                'usuario_id'=>Auth::user()->id,
                'observacoes'=>$request->observacoes,
                ]);
            
            return redirect('contaspagar');

        } else {

            return redirect()->back()->withInput()->withErrors(['Valor inválido!']);

        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        
        $parcela = Parcela::find($id);
        $parcela->delete();
        return redirect()->back();
        // $pagamento = Pagamento::with('parcelas')->find($id);
        // foreach ($pagamento->parcelas as $item) {
        //     $item->delete();
        // }
        // $pagamento->delete();
        // return redirect()->back();
        
    }

    public function destroyAll($id)
    {
        
        $pagamento = Pagamento::with('parcelas')->find($id);
        foreach ($pagamento->parcelas as $item) {
            $item->delete();
        }
        $pagamento->delete();
        return redirect()->back();

    }

    public function listarParcelas(Request $request)
    {
        $pagamento = Pagamento::with('parcelas', 'fornecedor')->find($request->pagamento);
        // dd($pagamento);
        return view('pages.contaspagar.listar-parcelas', compact('pagamento'));
    }

}
