<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;

use Appweb\Libraries\Util;
use Appweb\Promissoria;
use Appweb\Parcela;
use Appweb\Caixa;
use Appweb\Provisionado;
use Appweb\Pedido;
use Appweb\Cliente;

class ContasReceberController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        
        // dd($request);
        if ($request->has('filtro')) {

            if ($request->has('cliente')) {

                if ($request->filtro == "A vencer") {

                    $busca = Parcela::with('promissoria', 'cliente')
                        ->where("cliente_id", $request->cliente)
                        ->whereRaw("
                            date(vencimento) between '{$request->datainicial}' and '{$request->datafinal}'
                            ")
                            ->where('saldo', '>', 0)
                            ->whereNotNull('promissoria_id')
                            ->orderBy('vencimento')
                            ->paginate(15);
                    
                } else if ($request->filtro == "Quitadas") {

                    $busca = Parcela::with('promissoria', 'cliente')
                        ->where("cliente_id", $request->cliente)
                        ->whereRaw("
                            date(quitacao) between '{$request->datainicial}' and '{$request->datafinal}'
                            ")
                            ->where('saldo', 0)
                            ->whereNotNull('promissoria_id')
                            ->orderBy('vencimento')
                            ->paginate(15);

                }

            } else {
                if ($request->filtro == "A vencer") {

                    
                    $busca = Parcela::with('promissoria', 'cliente')->whereRaw("
                        date(vencimento) between '{$request->datainicial}' and '{$request->datafinal}'
                        ")
                        ->where('saldo', '>', 0)
                        ->whereNotNull('promissoria_id')
                        ->orderBy('vencimento')
                        ->paginate(15);
                    // dd($request->filtro);

                } else if ($request->filtro == "Quitadas") {

                   $busca = Parcela::with('promissoria', 'cliente')->whereRaw("
                        date(quitacao) between '{$request->datainicial}' and '{$request->datafinal}'
                        ")
                        ->where('saldo', 0)
                        ->whereNotNull('promissoria_id')
                        ->orderBy('vencimento')
                        ->paginate(15);

                }
                
            }

        } else {
            
            if (env('DB_CONNECTION') == 'sqlite') {

                $busca = Parcela::with('promissoria', 'cliente')->whereRaw("
                    date(vencimento) > datetime('now', '-7 DAY') 
                    ")
                    ->where('saldo', '>', 0)
                    ->whereNotNull('promissoria_id')
                    ->orderBy('id', 'desc')
                    ->paginate(15);

            } else {

                if ($request->has('busca')) {

                    $busca = Parcela::with('promissoria', 'cliente')->whereHas('cliente', function($q) use ($request) {
                        $q->where('nome', 'like', '%'.$request->busca.'%');
                        $q->orWhere('cliente_id', $request->busca);
                    })
                        ->where('saldo', '>', 0)
                        ->whereNotNull('promissoria_id')
                        ->orderBy('id', 'desc')
                        ->paginate(15);

                } else {

                    $busca = Parcela::with('promissoria', 'cliente')->whereRaw("
                        date(vencimento) BETWEEN CURRENT_DATE - INTERVAL 7 DAY AND CURRENT_DATE()
                        ")
                        ->where('saldo', '>', 0)
                        ->whereNotNull('promissoria_id')
                        ->orderBy('id', 'desc')
                        ->paginate(15);

                }

            }

        }

        // dd($busca);
        $soma = $busca->sum('valor');
        $clientes = Cliente::orderBy('nome')->lists('nome', 'id')->toArray();
        $modulo = "Contas a Receber";
        return view('pages.contasreceber.index', compact('modulo', 'busca', 'soma', 'clientes'));

    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  Request  $request
     * @return Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  Request  $request
     * @param  int  $id
     * @return Response
     */
    public function receberPromissoria(Request $request)
    {
        
        // return $request->all();
        $provisionado = Provisionado::first();
        $parcela = Parcela::with('cliente', 'promissoria')->find($request->promissoria);
        $promissoria = Promissoria::with('pedido')->find($parcela->promissoria->id);
        $parcela->valor = Util::toFloat($request->valor);
        $parcela->save();
        Caixa::create([
            'registro' => Util::toFloat($request->promissoria),
            'formapagamento' => $request->tipo,
            'tipomovimento' => 'Promissória',
            'bandeiracartao' => $request->bandeiracartao,
            'valor' => Util::toFloat($request->valor),
            'data' => date("Y-m-d H:i:s"),
            'observacoes' => "RECEBIMENTO - Promissória | " . $promissoria->pedido->tipo . " (".$parcela->promissoria->id.")",
            'movimento' => "E",
        ]);
        if ($request->tipo == "Dinheiro") {
            $provisionado->saldo = $provisionado->saldo + Util::toFloat($request->valor);
            $provisionado->save();
        }
        $parcela->update([
            'saldo'=>0,
            'quitacao'=>$request->dataquitacao,
            'cliente_id'=>$parcela->cliente,
            ]);
        $sit = Parcela::with('cliente', 'promissoria')
            ->where('promissoria_id', $parcela->promissoria->id)
            ->where('saldo', '>', 0)
            ->get();

            if (count($sit) == 0) { 
                $parcela->promissoria->status = "Quitada";
                $parcela->promissoria->save();
            }

        return redirect('caixa');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $promissoria = Parcela::find($id);
        $promissoria->delete();
        return redirect()->back();
    }

    public function listarParcelas(Request $request)
    {
        
        $promissoria = Promissoria::with('parcelas', 'cliente')->find($request->promissoria);
        $pedido = Pedido::with('itens')->find($promissoria->pedido_id);
        // dd($promissoria);
        return view('pages.contasreceber.listar-parcelas', compact('promissoria', 'pedido'));

    }

}
