<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Libraries\Util;

use Appweb\Entrada;
use Appweb\EntradaItem;
use Appweb\EntradaTemp;
use Appweb\Produto;
use Appweb\Fornecedor;
use Appweb\User;
use Session;
use DB;
use Auth;

class EstoqueController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        return view('pages.estoque.home')
            ->with("modulo", "Estoque");
    }

    public function movimento(Request $request)
    {
        
        if ($request->has('datainicial') && $request->has('datafinal')) {

            $busca = Entrada::whereRaw("
                date(data) between '{$request->datainicial}' and '{$request->datafinal}'
                ")
                ->orderBy('id', 'desc')
                ->paginate(15);

        } else {
            
            $db = env('DB_CONNECTION');

            if ($db == 'sqlite') {

                $busca = Entrada::whereRaw("
                    date(data) > datetime('now', '-7 DAY') 
                    ")
                    ->orderBy('id', 'desc')
                    ->paginate(15);

            } else {

                $busca = Entrada::whereRaw("
                    date(data) BETWEEN CURRENT_DATE - INTERVAL 7 DAY AND CURRENT_DATE
                    ")
                    ->orderBy('id', 'desc')
                    ->paginate(15);

            }

        }

        return view('pages.estoque.movimento', compact('busca'))
            ->with("modulo", "Estoque");
    }

    public function create()
    {
        
        if (Session::has("terminal")) :
            $terminal = Session::get("terminal");
            EntradaTemp::where("terminal", $terminal)->delete();
        else :
            $terminal = Session::put("terminal", md5(Util::gera_numero(10)));
        endif;
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        $catalogo = Produto::lists('descricao', 'referencia')->toArray();
        return view('pages.estoque.form', compact('terminal', 'fornecedores', 'catalogo'))
            ->with("modulo", "Estoque")
            ->with('legenda', 'Entrada de Produtos');
    }

    public function jsonProdutos(Request $request) 
    {

        $busca = $request->referencia;

        $r = Produto::where('referencia', '=', $busca)
                ->orWhere('descricao', 'like', '%' . $busca . '%')
                ->get();

        if (count($r) > 0) 
            return $r;
        else
            return 0;

    }

    public function adicionarItem(Request $request) 
    {

        $entrada = EntradaTemp::where("referencia", $request->referencia)
            ->where("entrada", $request->entrada)
            ->first();

        if (count($entrada) > 0) {

            $entrada->quantidade = $entrada->quantidade + $request->quantidade;
            $entrada->valor      = $request->valor;
            $entrada->subtotal   = $entrada->quantidade * $entrada->valor; 
            $entrada->save();

        } else {

            $add = new EntradaTemp();
            $add->data = date("Y-m-d");
            $add->referencia = $request->referencia;
            $add->descricao = $request->descricao;
            $add->quantidade = $request->quantidade;
            $add->unidade = $request->unidade;
            $add->valor = $request->valor;
            $add->subtotal = $request->quantidade * $request->valor;
            $add->terminal = $request->terminal;
            $add->entrada = $request->entrada;
            $add->save();

        }

    }

    public function excluirItem(Request $request) 
    {
        
        $entrada = $request->entrada;
        $referencia = $request->referencia;
        EntradaTemp::where("entrada", $entrada)->where("referencia", $referencia)->delete();

    }

    public function quantidadeItens(Request $request) 
    {
        
        $entrada = $request->entrada;
        $itens = EntradaTemp::select(DB::raw('count(*) AS ITENS'))
            ->where("entrada", $entrada)
            ->first();
        return $itens->ITENS;

    }

    public function totalEntradaTemp(Request $request) 
    {
        
        $entrada = $request->entrada;
        $total = EntradaTemp::select(DB::raw('sum(quantidade*valor) AS TOTAL'))
            ->where("entrada", $entrada)
            ->first();
        return Util::decimal2($total->TOTAL);

    }

    public function listarItensTemp(Request $request) 
    {

        $entrada = $request->entrada;
        $itens = EntradaTemp::select(DB::raw('*, sum(quantidade*valor) as subTotal'))
            ->where("entrada", $entrada)
            ->groupBy('referencia')
            ->get();
        return view('pages.estoque.listar-itens-temp', compact('itens'));

    }

    public function gerarEntrada(Request $request)
    {
        
        $total = EntradaTemp::where("entrada", $request->entrada)
            ->sum("subtotal");
        $et = EntradaTemp::where("entrada", $request->entrada)
            ->get();
        
        $entrada = Entrada::create([
            'data'=>date("Y-m-d H:i:s"),
            'nf'=>$request->nf,
            'data_nf'=>$request->datanf,
            'quantidade_itens'=>count($et),
            'total'=>$total,
            'fornecedor'=>$request->fornecedor,
            'usuario'=>Auth::user()->id,
            'observacoes'=>$request->observacoes,
            ]);

        foreach ($et as $item) {
            
            EntradaItem::create([
                'entrada'=>$entrada->id,
                'referencia'=>$item->referencia,
                'descricao'=>$item->descricao,
                'quantidade'=>$item->quantidade,
                'unidade'=>$item->unidade,
                'valor'=>$item->valor,
                'subtotal'=>$item->valor * $item->quantidade,
            ]);

            $produto = Produto::where('referencia', $item->referencia)->first();
            $produto->estoque = $produto->estoque + $item->quantidade;
            $produto->save();

        }

        EntradaTemp::where("terminal", $request->terminal)->delete();
        return redirect('estoque/entrada/sucesso?entrada=' . $entrada->id);

    }

    public function sucesso(Request $request) 
    {

        $entrada = Entrada::find($request->entrada);
        return view('pages.estoque.sucesso')
            ->with("nf", $entrada->nf)
            ->with("total", $entrada->total)
            ->with("modulo", "Estoque");

    }

    public function listarItensEntrada(Request $request)
    {
        
        $entrada     = Entrada::with('itens')->find($request->entrada);
        $fornecedor  = Fornecedor::find($entrada->fornecedor);
        $usuario   = User::find($entrada->usuario);
        return view('pages.estoque.listar-itens-entrada')
            ->with('entrada', $entrada)
            ->with('fornecedor', $fornecedor->nome)
            ->with('usuario', $usuario->nome);

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $entrada     = Entrada::with('itens')->find($id);
        foreach ($entrada as $item) {
            $produto = Produto::where('referencia', $item->referencia)->first();
            $produto->estoque = $produto->estoque - $item->quantidade;
            $produto->save();
            $item->delete();
        }
        $entrada->delete();
        return redirect()->back();
    }

}
