<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;

use Appweb\Fornecedor;
use Appweb\Cidade;
use Appweb\Estado;

class FornecedoresController extends Controller
{
    
    private $fornecedor;

    public function __construct(Fornecedor $fornecedor)
    {
        $this->fornecedor = $fornecedor;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        if ($request->has('busca')) {
            $busca = Fornecedor::where('id', $request->busca)
                ->orWhere('nome', 'like', '%'.$request->busca.'%')
                ->orderBy('nome')
                ->paginate(15);
        } else {
            $busca = Fornecedor::orderBy('nome')
                ->paginate(15);
        }

        return view('pages.cadastros.fornecedores.index')
            ->with("modulo", "Fornecedores")
            ->with('busca', $busca);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $cidades = Cidade::where('estado', 'PE')->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')->lists('nome', 'codigo')->toArray();
        return view('pages.cadastros.fornecedores.form')
            ->with('estados', $estados)
            ->with('cidades', $cidades)
            ->with("modulo", "Fornecedores")
            ->with('legenda', 'Fornecedor - Novo');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
         $regras = [
            'nome'=>'required', 
            'cpfcnpj'=>'unique:fornecedores', 
            ];
        $mensagens = [
            'nome.required'=>'Preencha o Nome', 
            // 'cpfcnpj.required'=>'Informe o CPF/CNPJ',
            'cpfcnpj.unique'=>'CPF/CNPJ já existe', 
            ];
        $this->validate($request,$regras,$mensagens);
        $this->fornecedor->create([
            'nome'=>$request->nome, 
            'endereco'=>$request->endereco, 
            'bairro'=>$request->bairro,
            'cep'=>$request->cep,
            'cidade'=>intval($request->cidade),
            'estado'=>intval($request->estado),
            'telefone'=>$request->telefone, 
            'telefone2'=>$request->telefone2, 
            'celular'=>$request->celular, 
            'celular2'=>$request->celular2,
            'email'=>$request->email,
            'cpfcnpj'=>$request->cpfcnpj,
            'observacoes'=>$request->observacoes
            ]);
        return redirect('cadastros/fornecedores');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $fornecedor = $this->fornecedor->find($id);
        $cidades = Cidade::where('estadocodigo', $fornecedor->estado)
            ->lists('nome', 'codigo')->toArray();
        $estados = Estado::orderBy('nome')->lists('nome', 'codigo')->toArray();
        return view('pages.cadastros.fornecedores.form', compact('fornecedor', 'estados', 'cidades'))
            ->with('legenda', 'Edição');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id, Request $request)
    {
        $regras = [
            'nome'=>'required', 
            // 'cpfcnpj'=>'required', 
            ];
        $mensagens = [
            'nome.required'=>'Preencha o Nome', 
            // 'cpfcnpj.required'=>'Informe o CPF/CNPJ',
            // 'cpfcnpj.unique'=>'CPF/CNPJ já existe', 
            ];
        $this->validate($request,$regras,$mensagens);
        
        $fornecedor             = $this->fornecedor->find($id);
        $fornecedor->nome       = $request->nome; 
        $fornecedor->endereco   = $request->endereco; 
        $fornecedor->bairro     = $request->bairro;
        $fornecedor->cep        = $request->cep;
        $fornecedor->cidade     = intval($request->cidade);
        $fornecedor->estado     = intval($request->estado);
        $fornecedor->telefone   = $request->telefone; 
        $fornecedor->telefone2  = $request->telefone2; 
        $fornecedor->celular    = $request->celular; 
        $fornecedor->celular2   = $request->celular2;
        $fornecedor->email      = $request->email;
        $fornecedor->cpfcnpj    = $request->cpfcnpj;
        $fornecedor->observacoes= $request->observacoes;
        // $fornecedor->fill($request->all());
        $fornecedor->save();

        return redirect('cadastros/fornecedores');
        
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->fornecedor->find($id)->delete();
        return redirect()->back();
    }
}
