<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;

use Appweb\Insumo;
use Appweb\CategoriaProduto;
use Appweb\Fornecedor;

class InsumosController extends Controller
{
    private $insumo;
    private $categoria;

    public function __construct(Insumo $insumo, CategoriaProduto $categoria)
    {
        $this->insumo = $insumo;
        $this->categoria = $categoria;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        
        if ($request->has('busca')) {
            $busca = $this->insumo->where('referencia', 'like', '%'.$request->busca.'%')
                ->orWhere('descricao', 'like', '%'.$request->busca.'%')
                ->orderBy('descricao')
                ->paginate(15);
        } else {
            $busca = $this->insumo->orderBy('descricao')
                ->paginate(15);
        }
        // dd($busca);
        return view('pages.cadastros.insumos.index', compact('busca'));
    
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        return view('pages.cadastros.insumos.form', compact('fornecedores'))
            ->with("modulo", "Produtos")
            ->with('legenda', 'Produto - Novo');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
        $regras = [
            'referencia'=>'required|max:13|unique:insumos', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            ];
        $mensagens = [
            'referencia.required'=>'Preencha o Código', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            ];
        $this->validate($request,$regras,$mensagens);
        $this->insumo->create([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>($request->has('categoria')) ? $request->categoria : null,
            'valor'=>toFloat($request->valor),
            'valor2'=>toFloat($request->valor2), 
            'valorprazo'=>toFloat($request->valorprazo), 
            'valorprazo2'=>toFloat($request->valorprazo2),
            'estoque'=>($request->has('estoque')) ? $request->estoque : 0,
            ]);
        return redirect('cadastros/insumos');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $insumo = $this->insumo->find($id);
        $fornecedores = Fornecedor::lists('nome', 'id')->toArray();
        $categorias = $this->categoria->lists('descricao', 'codigo')->toArray();
        return view('pages.cadastros.insumos.form', compact('insumo', 'categorias', 'fornecedores'))
            ->with("modulo", "Produtos")
            ->with('legenda', 'Edição');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id, Request $request)
    {
        $regras = [
            'referencia'=>'required|max:13', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            ];
        $mensagens = [
            'referencia.required'=>'Preencha o Código', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            ];
        $this->validate($request,$regras,$mensagens);
        $insumo = $this->insumo->find($id);
        $insumo->update([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>($request->has('categoria')) ? $request->categoria : null,
            'valor'=>toFloat($request->valor),
            'valor2'=>toFloat($request->valor2), 
            'valorprazo'=>toFloat($request->valorprazo), 
            'valorprazo2'=>toFloat($request->valorprazo2),
            'estoque'=>($request->has('estoque')) ? $request->estoque : 0,
            ]);
        return redirect('cadastros/insumos');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->insumo->find($id)->delete();
        return redirect()->back();
    }

}
