<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Loja;

class LojasController extends Controller
{
    private $loja;

    public function __construct(Loja $loja)
    {
        $this->loja = $loja;
        view()->share(['modulo'=>'Lojas']);
    }

    public function index(Request $request)
    {

        if ($request->has('busca')) {
            
            $busca = $this->loja
                ->where('nome_fantasia', 'like', '%'.$request->busca.'%')
                ->orderby("id", "desc")
                ->paginate(15);
            
        } else {
            
            $busca = $this->loja
                ->orderby("id", "desc")
                ->paginate(15);

        }
        // dd($busca);
        return view('pages.cadastros.lojas.index', compact('busca'));

    }

    public function impressao(Request $request)
    {
        
        $dados = $this->loja
            ->orderby('id', 'desc')
            ->get();
        $view = view('pages.cadastros.lojas.impressao', compact('dados'));
        return impressaoPDF($view, ["titulo"=>"Listagem de Lojas"]);

    }

    public function create()
    {

        return view('pages.cadastros.lojas.form');

    }

    public function edit($id="")
    {

        if (!empty($id)) {

            $loja = $this->loja->find($id);
            return view('pages.cadastros.lojas.form', compact('loja'));

        } else {

            return redirect('cadastros/lojas');

        }

    }

    public function store(Request $request)
    {
        
        $regras = array(
            // 'razao_social' => 'required',
            'nome_fantasia' => 'required',
            // 'cnpj' => 'required',
            // 'inscricao_estadual' => 'required',
            // 'telefone' => 'required',
            // 'email' => 'required',
            // 'responsavel' => 'required',
            // 'Loja' => 'required',
            );
        $mensagens = array(
            // 'razao_social.unique' => 'Preencher Razão Social.',
            'nome_fantasia.required' => 'Prencher Nome Fantasia',
            // 'cnpj.required' => 'Preencher CNPJ',
            // 'inscricao_estadual.required' => 'Preencher Inscrição Estadual',
            // // 'telefone.required' => 'Preencher Telefone',
            // 'email.required' => 'Preencher Email',
            // 'responsavel.required' => 'Preencher Responsável',
            // 'Loja.required' => 'Selecionar Loja',
            );
        
        $this->validate($request,$regras,$mensagens);
        
        $loja = new $this->loja;
        $loja->razao_social = $request->input("razao_social");
        $loja->nome_fantasia = $request->input("nome_fantasia");
        $loja->cnpj = $request->input("cnpj");
        $loja->inscricao_estadual = $request->input("inscricao_estadual");
        $loja->logradouro = $request->input("logradouro");
        $loja->bairro = $request->input("bairro");
        $loja->cep = $request->input("cep");
        $loja->cidade = $request->input("cidade");
        $loja->estado = $request->input("estado");
        $loja->telefone = $request->input("telefone");
        $loja->celular = $request->input("celular");
        $loja->email = $request->input("email");
        $loja->responsavel = $request->input("responsavel");
        $loja->status = 1;
        $loja->save();
        
        return redirect('cadastros/lojas');

    }

    public function update(Request $request, $id="")
    {
                    
        if (!empty($id)) {
            
            $regras = array(
                // 'razao_social' => 'required',
                'nome_fantasia' => 'required',
                // 'cnpj' => 'required',
                // 'inscricao_estadual' => 'required',
                // 'telefone' => 'required',
                // 'email' => 'required',
                // 'responsavel' => 'required',
                // 'Loja' => 'required',
                );
            $mensagens = array(
                // 'razao_social.unique' => 'Preencher Razão Social.',
                'nome_fantasia.required' => 'Prencher Nome Fantasia',
                // 'cnpj.required' => 'Preencher CNPJ',
                // 'inscricao_estadual.required' => 'Preencher Inscrição Estadual',
                // 'telefone.required' => 'Preencher Telefone',
                // 'email.required' => 'Preencher Email',
                // 'responsavel.required' => 'Preencher Responsável',
                // 'Loja.required' => 'Selecionar Loja',
                );
            
            $this->validate($request,$regras,$mensagens);

            $loja = $this->loja->find($id);
            $loja->razao_social = $request->input("razao_social");
            $loja->nome_fantasia = $request->input("nome_fantasia");
            $loja->cnpj = $request->input("cnpj");
            $loja->inscricao_estadual = $request->input("inscricao_estadual");
            $loja->logradouro = $request->input("logradouro");
            $loja->bairro = $request->input("bairro");
            $loja->cep = $request->input("cep");
            $loja->cidade = $request->input("cidade");
            $loja->estado = $request->input("estado");
            $loja->telefone = $request->input("telefone");
            $loja->celular = $request->input("celular");
            $loja->email = $request->input("email");
            $loja->responsavel = $request->input("responsavel");
            $loja->status = ($request->input('status') == "1") ? 1 : 0;
            $loja->save();
            
        }
        
        return redirect('cadastros/lojas');

    }

    public function destroy($id="")
    {

        if (!empty($id)) {

            $this->loja->find($id)->delete();
            return redirect('cadastros/lojas');

        } else {

            return redirect('cadastros/lojas');

        }

    }

}
