<?php

namespace Appweb\Http\Controllers;

use Illuminate\Http\Request;

use Appweb\Http\Requests;
use Appweb\Http\Controllers\Controller;
use Appweb\Libraries\Util;

use Appweb\Servico;
use Appweb\CategoriaServico;

class ServicosController extends Controller
{
    
    private $servico;

    public function __construct(Servico $servico)
    {
        $this->servico = $servico;
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(Request $request)
    {
        if ($request->has('busca')) {
            $busca = Servico::where('descricao', 'like', '%'.$request->busca.'%')
                ->orWhere('referencia', 'like', '%'.$request->busca.'%')
                ->orderBy('descricao')
                ->paginate(15);
        } else {
            $busca = Servico::orderBy('descricao')
                ->paginate(15);
        }

        return view('pages.cadastros.servicos.index')
            ->with("modulo", "Serviços")
            ->with('busca', $busca);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $categorias = CategoriaServico::lists('descricao', 'codigo')->toArray();
        return view('pages.cadastros.servicos.form')
            ->with('categorias', $categorias)
            ->with("modulo", "Serviços")
            ->with('legenda', 'Serviço - Novo');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store(Request $request)
    {
        
        $regras = [
            'referencia'=>'required|max:13|unique:servicos', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            'categoria'=>'required', 
            ];
        $mensagens = [
            'referencia.required'=>'Preencha o Código', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'referencia.unique'=>'Referência já existe', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            'categoria.required'=>'Selecione uma Categoria',
            ];
        $this->validate($request,$regras,$mensagens);
        $this->servico->create([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>$request->categoria,
            'valor'=>Util::toFloat($request->valor), 
            'valor2'=>Util::toFloat($request->valor2), 
            'valorprazo'=>Util::toFloat($request->valorprazo), 
            'valorprazo2'=>Util::toFloat($request->valorprazo2),
            ]);
        return redirect('cadastros/servicos');

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $servico = $this->servico->find($id);
        $categorias = CategoriaServico::lists('descricao', 'codigo')->toArray();
        return view('pages.cadastros.servicos.form', compact('servico', 'categorias'))
            ->with('legenda', 'Edição');
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id, Request $request)
    {
        
        $regras = [
            'referencia'=>'required|max:13', 
            'descricao'=>'required', 
            'valor'=>'required', 
            'unidade'=>'required',
            'categoria'=>'required', 
            ];
        $mensagens = [
            'referencia.required'=>'Preencha a Referência', 
            'referencia.max'=>'O máximo de caracteres na Referência é 13', 
            'descricao.required'=>'Preencha a Descrição', 
            'valor.required'=>'Informe o Valor Comum', 
            'unidade.required'=>'Selecione a Unidade',
            'categoria.required'=>'Selecione uma Categoria',
            ];
        $this->validate($request,$regras,$mensagens);
        $servico = $this->servico->find($id);
        $servico->update([
            'referencia'=>$request->referencia, 
            'descricao'=>$request->descricao, 
            'unidade'=>$request->unidade,
            'categoria'=>$request->categoria,
            'valor'=>Util::toFloat($request->valor), 
            'valor2'=>Util::toFloat($request->valor2), 
            'valorprazo'=>Util::toFloat($request->valorprazo), 
            'valorprazo2'=>Util::toFloat($request->valorprazo2),
            ]);
        return redirect('cadastros/servicos');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $this->servico->find($id)->delete();
        return redirect()->back();
    }
}
