<?php

//-- Ferramentas --//

Route::get('/ferramentas/empresa', 'EmpresaController@index')
    ->name('ferramentas.empresa');
Route::post('/ferramentas/empresa/salvar', 'EmpresaController@salvar')
    ->name('ferramentas.empresa.salvar');
Route::post('/ferramentas/empresa/{id?}/atualizar', 'EmpresaController@atualizar')
    ->name('ferramentas.empresa.atualizar');

//-- Faturas --//

Route::get('/fatura',            ['as'=>'fatura',            'uses'=>'PrincipalController@faturas']);
Route::get('/foradoar', 'PrincipalController@foradoar')->name('foradoar');

//-- Configurações --//

Route::get('configuracoes',         array('middleware' => 'auth', 'uses' => 'ConfiguracoesController@index'));
Route::post('configuracoes/salvar', array('middleware' => 'auth', 'uses' => 'ConfiguracoesController@salvar'));

//-- Home --//

Route::get('/', array('middleware' => 'auth', 'uses' => 'PrincipalController@index'))->name('index');

//-- Login --//

Route::get('login', 'LoginController@index');
Route::post('login/autorizar', 'LoginController@autorizar');
Route::get('login/logout', 'LoginController@logout');
Route::get('login/perfil', array('middleware' => 'auth', 'uses' => 'LoginController@perfil'));
Route::post('login/salvar/{id?}', 'LoginController@update');


Route::get('db/migrate-news', function() {
    // Artisan::call('db:seed');
    $migrate = Artisan::call('db:seed', [
        '--class' => 'ConfiguracoesTableSeeder'
    ]);
    return redirect()->back();
});

Route::get('usuarios/criar', function() {

    Appweb\User::create([
        'nome'=>'Waldênia Lucena', 
        'login'=>'katia', 
        'password'=>Hash::make('123'), 
        'nivel'=>'Administrador', 
        ]);

    Appweb\User::create([
        'nome'=>'André Lucena', 
        'login'=>'andre', 
        'password'=>Hash::make('123'), 
        'nivel'=>'Administrador', 
        ]);

    return redirect('login/logout');

});

//-- Cidades --//

    get('cidades/listar-cidades-por-estado/{estado}', 'CidadesController@showByState');

//-- Pedidos --//

Route::group(array('prefix' => 'pedidos', "middleware" => "auth"), function()
{

    Route::get('/', 'PedidosController@index');

    // Venda

    Route::get('dados', function() {

        $po = Appweb\Pedido::find(Request::get('pedido'));
        $dados['cliente']       = $po->cliente_id;
        $dados['observacoes']   = $po->observacoes;
        return $dados;

    });

    Route::get('venda', 'PedidosController@venda');
    Route::get('servico', 'PedidosController@servico');
    Route::get('cliente/novo', 'PedidosController@clienteNovo');
    Route::get('listarClientes', 'PedidosController@listarClientes');
    Route::get('json-vendas', 'PedidosController@jsonProdutos');
    Route::get('json-servicos', 'PedidosController@jsonServicos');
    Route::get('listar-itens', 'PedidosController@listarItens');
    Route::get('listar-itens-orcamento', 'PedidosController@listarItensTemp');
    Route::get('adicionarItem', 'PedidosController@adicionarItem');
    Route::get('quantidade-itens', 'PedidosController@quantidadeItens');
    Route::get('total-pedido-temp', 'PedidosController@totalPedidoTemp');
    Route::get('excluirItem', 'PedidosController@excluirItem');
    Route::post('finalizar', 'PedidosController@gerarPedido');
    Route::get('sucesso', 'PedidosController@sucesso');
    Route::get('teste', 'PedidosController@teste');

});

//-- Ordens de Serviço --//

Route::group(['prefix' => 'os', 'middleware'=>'auth'], function() {

    get('',                             ['as'=>'os', 'uses'=>'OrdensDeServicosController@index']);
    get('/adicionar/{tipo?}',           ['as'=>'os.adicionar', 'uses'=>'OrdensDeServicosController@os']);
    post('/finalizar/{tipo?}',          ['as'=>'os.finalizar', 'uses'=>'OrdensDeServicosController@store']);
    get('/sucesso/{os}/{tipo?}',        ['as'=>'os.sucesso', 'uses'=>'OrdensDeServicosController@sucesso']);
    post('/cancelar/{id}/{tipo?}',      ['as'=>'os.cancelar', 'uses'=>'OrdensDeServicosController@destroy']);
    get('/listar-itens',                ['as'=>'os.listar-itens', 'uses'=>'OrdensDeServicosController@listarItens']);

});

//-- Consultas --//

Route::group(array('prefix' => 'consultas', "middleware" => "auth"), function()
{

    Route::get('/', 'ConsultasController@index');
        get('pedidos/listar-itens', 'ConsultasController@listarItens');
        post('pedidos/cancelar/{pedido}', 'ConsultasController@cancelar');

});

//-- Caixa --//

Route::group(array('prefix' => 'caixa', "middleware" => "auth"), function()
{

    Route::get('/', 'CaixaController@index');
        get('resumo', 'CaixaController@resumo');
        post('movimentacao', 'CaixaController@store');

});

//-- Cadastros --//

Route::group(array('prefix' => 'cadastros', "middleware" => "auth"), function()
{

    Route::get('/', 'PrincipalController@cadastros');
    // Produtos
    Route::get('produtos', 'ProdutosController@index');
        get('produtos/novo', 'ProdutosController@create');
        post('produtos/novo', 'ProdutosController@store');
        get('produtos/adicionar', 'ProdutosController@produtoNovo');
        get('produtos/editar/{id}', 'ProdutosController@edit');
        post('produtos/atualizar/{id}', 'ProdutosController@update');
        post('produtos/excluir/{id}', 'ProdutosController@destroy');
        get('produtos/listar-produtos', 'ProdutosController@listarProdutos');
    // Serviços
    Route::get('servicos', 'ServicosController@index');
        get('servicos/novo', 'ServicosController@create');
        post('servicos/novo', 'ServicosController@store');
        get('servicos/editar/{id}', 'ServicosController@edit');
        post('servicos/atualizar/{id}', 'ServicosController@update');
        post('servicos/excluir/{id}', 'ServicosController@destroy');
    // Clientes
    Route::get('clientes', 'ClientesController@index');
        get('clientes/novo', 'ClientesController@create');
        get('clientes/listar-clientes', 'ClientesController@listarClientes');
        post('clientes/novo', 'ClientesController@store');
        get('clientes/editar/{id}', 'ClientesController@edit');
        post('clientes/atualizar/{id}', 'ClientesController@update');
        post('clientes/excluir/{id}', 'ClientesController@destroy');
    // Fornecedores
    Route::get('fornecedores', 'FornecedoresController@index');
        get('fornecedores/novo', 'FornecedoresController@create');
        post('fornecedores/novo', 'FornecedoresController@store');
        get('fornecedores/editar/{id}', 'FornecedoresController@edit');
        post('fornecedores/atualizar/{id}', 'FornecedoresController@update');
        post('fornecedores/excluir/{id}', 'FornecedoresController@destroy');
    Route::get('usuarios', 'UsuariosController@index');
        get('usuarios/novo', 'UsuariosController@create');
        post('usuarios/novo', 'UsuariosController@store');
        get('usuarios/editar/{id}', 'UsuariosController@edit');
        post('usuarios/atualizar/{id}', 'UsuariosController@update');
        post('usuarios/excluir/{id}', 'UsuariosController@destroy');
    Route::get('lojas', 'LojasController@index');
        get('lojas/adicionar', 'LojasController@create');
        post('lojas/adicionar', 'LojasController@store');
        get('lojas/editar/{id}', 'LojasController@edit');
        post('lojas/atualizar/{id}', 'LojasController@update');
        post('lojas/excluir/{id}', 'LojasController@destroy');
    Route::get('insumos', 'InsumosController@index');
        get('insumos/adicionar', 'InsumosController@create');
        post('insumos/adicionar', 'InsumosController@store');
        get('insumos/editar/{id}', 'InsumosController@edit');
        post('insumos/atualizar/{id}', 'InsumosController@update');
        post('insumos/excluir/{id}', 'InsumosController@destroy');
    Route::get('categorias/produtos', 'CategoriasProdutosController@index');
        get('categorias/produtos/adicionar', 'CategoriasProdutosController@create');
        post('categorias/produtos/adicionar', 'CategoriasProdutosController@store');
        get('categorias/produtos/editar/{id}', 'CategoriasProdutosController@edit');
        post('categorias/produtos/atualizar/{id}', 'CategoriasProdutosController@update');
        post('categorias/produtos/excluir/{id}', 'CategoriasProdutosController@destroy');

});

//-- Contas a Receber --//

Route::group(array('prefix' => 'contasreceber', "middleware" => "auth"), function()
{

    Route::get('/', 'ContasReceberController@index');
        get('listar-parcelas', 'ContasReceberController@listarParcelas');
        post('receber-promissoria', 'ContasReceberController@receberPromissoria');
        post('excluir-promissoria/{id}', 'ContasReceberController@destroy');

});

//-- Contas a Pagar --//

Route::group(array('prefix' => 'contaspagar', "middleware" => "auth"), function()
{

    Route::get('/', 'ContasPagarController@index');
        get('adicionar', 'ContasPagarController@create');
        post('adicionar', 'ContasPagarController@store');
        post('atualizar/{id}', 'ContasPagarController@update');
        get('editar/{id?}',          ['as'=>'contaspagar.editar', 'uses'=>'ContasPagarController@edit']);
        post('excluir/{id}', 'ContasPagarController@destroy');
        post('excluir-conta/{id}', 'ContasPagarController@destroyAll');
        get('listar-parcelas', 'ContasPagarController@listarParcelas');
        post('informar-pagamento', 'ContasPagarController@informarPagamento');

});

//-- Estoque --//

Route::group(array('prefix' => 'estoque', "middleware" => "auth"), function()
{

    Route::get('/', 'EstoqueController@index');
        get('movimento', 'EstoqueController@movimento');
        get('entrada/listar-itens-entrada', 'EstoqueController@listarItensEntrada');
        get('entrada', 'EstoqueController@create');
        get('balanco', 'EstoqueController@balanco');
        post('entrada/finalizar', 'EstoqueController@gerarEntrada');
        get('entrada/sucesso', 'EstoqueController@sucesso');
        post('entrada/cancelar/{id}', 'EstoqueController@destroy');
        // Nova Entrada
        get('entrada/json-produtos', 'EstoqueController@jsonProdutos');
        get('entrada/adicionar-item', 'EstoqueController@adicionarItem');
        get('entrada/listar-itens-temp', 'EstoqueController@listarItensTemp');
        get('entrada/quantidade-itens', 'EstoqueController@quantidadeItens');
        get('entrada/total-entrada-temp', 'EstoqueController@totalEntradaTemp');
        post('entrada/excluir-item', 'EstoqueController@excluirItem');

});
